<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>About</name>
    <message>
        <location filename="../ui/about.py" line="53"/>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="53"/>
        <source>Contributors</source>
        <translation>Contributeurs</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="53"/>
        <source>Translators</source>
        <translation>Traducteurs</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="75"/>
        <source>About Linux Show Player</source>
        <translation>À propos de Linux Show Player</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../ui/about.py" line="47"/>
        <source>Linux Show Player is a cue-player designed for stage productions.</source>
        <translation>Linux Show Player est un logiciel de lecture de cue conçu pour le théâtre ou l&apos;événementiel.</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="102"/>
        <source>Web site</source>
        <translation>Site web</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="102"/>
        <source>Users  group</source>
        <translation>Groupe d&apos;utilisateurs</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="102"/>
        <source>Source code</source>
        <translation>Code source</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="112"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="117"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../ui/about.py" line="123"/>
        <source>Contributors</source>
        <translation>Contributeurs</translation>
    </message>
</context>
<context>
    <name>AppGeneralSettings</name>
    <message>
        <location filename="../ui/settings/pages/app_general.py" line="39"/>
        <source>Startup layout</source>
        <translation>État de démarrage</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/app_general.py" line="45"/>
        <source>Use startup dialog</source>
        <translation>Utilisez le dialogue du démarrage</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/app_general.py" line="58"/>
        <source>Application theme</source>
        <translation>Thème de l&apos;application</translation>
    </message>
</context>
<context>
    <name>AppSettings</name>
    <message>
        <location filename="../ui/settings/app_settings.py" line="36"/>
        <source>LiSP preferences</source>
        <translation>Préférences de LiSP</translation>
    </message>
</context>
<context>
    <name>CartLayout</name>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="171"/>
        <source>Add page</source>
        <translation>Ajouter une page</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="196"/>
        <source>Add pages</source>
        <translation>Ajouter des pages</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="173"/>
        <source>Remove current page</source>
        <translation>Retirer la page actuelle</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="85"/>
        <source>Countdown mode</source>
        <translation>Compte à rebours </translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="86"/>
        <source>Show seek-bars</source>
        <translation>Montrer les barres de position</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="87"/>
        <source>Show dB-meters</source>
        <translation>Afficher le mesureur de dB</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="89"/>
        <source>Show volume</source>
        <translation>Afficher le volume</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="88"/>
        <source>Show accurate time</source>
        <translation>Afficher le temps exact</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="183"/>
        <source>Edit cue</source>
        <translation>Éditer la cue</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="184"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="185"/>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="186"/>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="187"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="188"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="189"/>
        <source>Reset volume</source>
        <translation>Réinitialisation du volume</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="196"/>
        <source>Number of Pages:</source>
        <translation>Nombre de pages :</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="276"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="277"/>
        <source>Every cue in the page will be lost.</source>
        <translation>Toutes les cues dans la pages seront perdues</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="279"/>
        <source>Are you sure to continue?</source>
        <translation>Voulez-vous vraiment continuer ?</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="298"/>
        <source>Page</source>
        <translation>Page</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="83"/>
        <source>Default behaviors</source>
        <translation>Comportements par défaut </translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="90"/>
        <source>Automatically add new page</source>
        <translation>Ajouter une page automatiquement</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="92"/>
        <source>Grid size</source>
        <translation>Taille de la grille</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="93"/>
        <source>Number of columns</source>
        <translation>Nombre de colonnes</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/cart_layout_settings.py" line="94"/>
        <source>Number of rows</source>
        <translation>Nombre de lignes</translation>
    </message>
</context>
<context>
    <name>CueAction</name>
    <message>
        <location filename="../ui/widgets/cueaction_combobox.py" line="28"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <location filename="../ui/widgets/cueaction_combobox.py" line="34"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../ui/widgets/cueaction_combobox.py" line="32"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../ui/widgets/cueaction_combobox.py" line="33"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../ui/widgets/cueaction_combobox.py" line="29"/>
        <source>FadeInStart</source>
        <translation>DémarrageDuFonduÀlOuverture</translation>
    </message>
    <message>
        <location filename="../ui/widgets/cueaction_combobox.py" line="30"/>
        <source>FadeOutStop</source>
        <translation>ArrêtduFonduÀlaFermeture</translation>
    </message>
    <message>
        <location filename="../ui/widgets/cueaction_combobox.py" line="31"/>
        <source>FadeOutPause</source>
        <translation>PauseduFonduÀlaFermeture</translation>
    </message>
</context>
<context>
    <name>CueActionLog</name>
    <message>
        <location filename="../cues/cue_actions.py" line="48"/>
        <source>Cue settings changed: &quot;{}&quot;</source>
        <translation>Paramètres de cue modifiés : &quot;{}&quot;</translation>
    </message>
    <message>
        <location filename="../cues/cue_actions.py" line="76"/>
        <source>Cues settings changed.</source>
        <translation>Paramètres de cues modifiés.</translation>
    </message>
</context>
<context>
    <name>CueAppearanceSettings</name>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="74"/>
        <source>The appearance depends on the layout</source>
        <translation>L&apos;apparence dépend de l&apos;agencement</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="83"/>
        <source>Cue name</source>
        <translation>Nom de la cue</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="85"/>
        <source>NoName</source>
        <translation>Pas de nom</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="87"/>
        <source>Description/Note</source>
        <translation>Description / note</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="89"/>
        <source>Set Font Size</source>
        <translation>Définir la taille de la police</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="91"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="92"/>
        <source>Select background color</source>
        <translation>Sélectionner la couleur de fond</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="94"/>
        <source>Select font color</source>
        <translation>Sélectionner la couleur de la police</translation>
    </message>
</context>
<context>
    <name>CueName</name>
    <message>
        <location filename="../cues/media_cue.py" line="33"/>
        <source>Media Cue</source>
        <translation>Cue de média</translation>
    </message>
</context>
<context>
    <name>CueSettings</name>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="177"/>
        <source>Pre wait</source>
        <translation>Pré-attente</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="178"/>
        <source>Wait before cue execution</source>
        <translation>Attente avant l&apos;exécution de la cue</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="181"/>
        <source>Post wait</source>
        <translation>Post-attente</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="182"/>
        <source>Wait after cue execution</source>
        <translation>Attente après l&apos;exécution de la cue</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="185"/>
        <source>Next action</source>
        <translation>Prochaine action</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_app_settings.py" line="55"/>
        <source>Interrupt Fade</source>
        <translation>Interrompre le fondu</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_app_settings.py" line="56"/>
        <source>Fade Action</source>
        <translation>Action de fondu</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="161"/>
        <source>Behaviours</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="162"/>
        <source>Pre/Post Wait</source>
        <translation>Attente pré/post</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="163"/>
        <source>Fade In/Out</source>
        <translation>Fondu à l&apos;ouverture/fermeture</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="166"/>
        <source>Start action</source>
        <translation>Lancer l&apos;action</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="168"/>
        <source>Default action to start the cue</source>
        <translation>Action par défaut pour démarrer la cue</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="171"/>
        <source>Stop action</source>
        <translation>Arrêter l&apos;action</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="173"/>
        <source>Default action to stop the cue</source>
        <translation>Action par défaut pour arrêter la cue</translation>
    </message>
</context>
<context>
    <name>Fade</name>
    <message>
        <location filename="../ui/widgets/fade_combobox.py" line="28"/>
        <source>Linear</source>
        <translation>Linéaire</translation>
    </message>
    <message>
        <location filename="../ui/widgets/fade_combobox.py" line="29"/>
        <source>Quadratic</source>
        <translation>Du second degré</translation>
    </message>
    <message>
        <location filename="../ui/widgets/fade_combobox.py" line="30"/>
        <source>Quadratic2</source>
        <translation>Du second degré 2</translation>
    </message>
</context>
<context>
    <name>FadeEdit</name>
    <message>
        <location filename="../ui/widgets/fade_edit.py" line="51"/>
        <source>Duration (sec)</source>
        <translation>Durée (sec)</translation>
    </message>
    <message>
        <location filename="../ui/widgets/fade_edit.py" line="52"/>
        <source>Curve</source>
        <translation>Courbe</translation>
    </message>
</context>
<context>
    <name>FadeSettings</name>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="188"/>
        <source>Fade In</source>
        <translation>Fondu à l&apos;ouverture</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="189"/>
        <source>Fade Out</source>
        <translation>Fondu à la fermeture</translation>
    </message>
</context>
<context>
    <name>LayoutDescription</name>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="47"/>
        <source>Organize cues in grid like pages</source>
        <translation>Organiser les cues en grille comme les pages</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="57"/>
        <source>Organize the cues in a list</source>
        <translation>Organiser les cues dans une liste</translation>
    </message>
</context>
<context>
    <name>LayoutDetails</name>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="50"/>
        <source>Click a cue to run it</source>
        <translation>Cliquer sur une cue pour l&apos;exécuter</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="51"/>
        <source>SHIFT + Click to edit a cue</source>
        <translation>MAJ + clic pour éditer une cue</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="52"/>
        <source>CTRL + Click to select a cue</source>
        <translation>CTRL + clic pour sélectionner une cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="60"/>
        <source>SHIFT + Space or Double-Click to edit a cue</source>
        <translation>MAJ + Espace ou double-clic pour éditer une cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="64"/>
        <source>To copy cues drag them while pressing CTRL</source>
        <translation>Pour copier les cues, glissez-les en pressant CTRL</translation>
    </message>
    <message>
        <location filename="../layouts/cart_layout/layout.py" line="55"/>
        <source>To copy cues drag them while pressing SHIFT</source>
        <translation>Pour copier les cues, glissez-les en pressant SHIFT</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="62"/>
        <source>CTRL + Left Click to select cues</source>
        <translation>CTRL + clic-gauche pour sélectionner les cues</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="66"/>
        <source>To move cues drag them</source>
        <translation>Pour déplacer des cues, déplacez-les</translation>
    </message>
</context>
<context>
    <name>LayoutSelect</name>
    <message>
        <location filename="../ui/layoutselect.py" line="38"/>
        <source>Layout selection</source>
        <translation>Sélection de l&apos;agencement</translation>
    </message>
    <message>
        <location filename="../ui/layoutselect.py" line="51"/>
        <source>Select layout</source>
        <translation>Sélectionner l&apos;agencement</translation>
    </message>
    <message>
        <location filename="../ui/layoutselect.py" line="55"/>
        <source>Open file</source>
        <translation>Ouvrir un fichier</translation>
    </message>
</context>
<context>
    <name>ListLayout</name>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="108"/>
        <source>Show playing cues</source>
        <translation>Montrer les cues en cours</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="109"/>
        <source>Show dB-meters</source>
        <translation>Afficher le mesureur de dB</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="111"/>
        <source>Show seek-bars</source>
        <translation>Montrer les barres de position</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="110"/>
        <source>Show accurate time</source>
        <translation>Afficher le temps exact</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="112"/>
        <source>Auto-select next cue</source>
        <translation>Auto-sélectionner la prochaine cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="208"/>
        <source>Edit cue</source>
        <translation>Éditer la cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="209"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/layout.py" line="210"/>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/control_buttons.py" line="62"/>
        <source>Stop all</source>
        <translation>Tout stopper</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/control_buttons.py" line="61"/>
        <source>Pause all</source>
        <translation>Tout mettre en pause</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/control_buttons.py" line="66"/>
        <source>Restart all</source>
        <translation>Tout redémarrer</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="63"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="64"/>
        <source>Restart</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="106"/>
        <source>Default behaviors</source>
        <translation>Comportements par défaut </translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="113"/>
        <source>At list end:</source>
        <translation>À la fin de la liste :</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="114"/>
        <source>Go key:</source>
        <translation>Touche pour lancer :</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/control_buttons.py" line="63"/>
        <source>Interrupt all</source>
        <translation>Tout interrompre</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/control_buttons.py" line="67"/>
        <source>Fade-Out all</source>
        <translation>Tout fondre à la fermeture</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/control_buttons.py" line="68"/>
        <source>Fade-In all</source>
        <translation>Tout fondre à l&apos;ouverture</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="116"/>
        <source>Use fade</source>
        <translation>Utiliser le fondu</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="117"/>
        <source>Stop Cue</source>
        <translation>Arrêter la cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="118"/>
        <source>Pause Cue</source>
        <translation>Mettre la cue en pause</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="119"/>
        <source>Restart Cue</source>
        <translation>Redémarrer la cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="120"/>
        <source>Interrupt Cue</source>
        <translation>Interrompre la cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="121"/>
        <source>Stop All</source>
        <translation>Tout arrêter</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="122"/>
        <source>Pause All</source>
        <translation>Tout mettre en pause</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="123"/>
        <source>Restart All</source>
        <translation>Tout redémarrer</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/list_layout_settings.py" line="124"/>
        <source>Interrupt All</source>
        <translation>Tout interrompre</translation>
    </message>
</context>
<context>
    <name>ListLayoutHeader</name>
    <message>
        <location filename="../layouts/list_layout/cue_list_view.py" line="46"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/cue_list_view.py" line="47"/>
        <source>Pre wait</source>
        <translation>Pré-attente</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/cue_list_view.py" line="48"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/cue_list_view.py" line="49"/>
        <source>Post wait</source>
        <translation>Post-attente</translation>
    </message>
</context>
<context>
    <name>ListLayoutInfoPanel</name>
    <message>
        <location filename="../layouts/list_layout/info_panel.py" line="50"/>
        <source>Cue name</source>
        <translation>Nom de la cue</translation>
    </message>
    <message>
        <location filename="../layouts/list_layout/info_panel.py" line="52"/>
        <source>Cue description</source>
        <translation>Description de la cue</translation>
    </message>
</context>
<context>
    <name>Logging</name>
    <message>
        <location filename="../ui/elogging.py" line="35"/>
        <source>Information</source>
        <translation>Informations</translation>
    </message>
    <message>
        <location filename="../ui/elogging.py" line="42"/>
        <source>Debug</source>
        <translation>Déboguage</translation>
    </message>
    <message>
        <location filename="../ui/elogging.py" line="49"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../ui/elogging.py" line="63"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../ui/elogging.py" line="69"/>
        <source>Details:</source>
        <translation>Détails :</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.py" line="149"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="150"/>
        <source>New session</source>
        <translation>Nouvelle session</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="152"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="154"/>
        <source>Save session</source>
        <translation>Sauvegarder la session</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="156"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="158"/>
        <source>Save as</source>
        <translation>Sauvegarder sous</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="160"/>
        <source>Full Screen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="162"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="164"/>
        <source>&amp;Edit</source>
        <translation>Édit&amp;er</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="165"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="167"/>
        <source>Redo</source>
        <translation>Refaire</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="169"/>
        <source>Select all</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="170"/>
        <source>Select all media cues</source>
        <translation>Sélectionner toutes les cues média</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="173"/>
        <source>Deselect all</source>
        <translation>Tout désélectionner </translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="174"/>
        <source>CTRL+SHIFT+A</source>
        <translation>CTRL+MAJ+A</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="175"/>
        <source>Invert selection</source>
        <translation>Inverser la sélection</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="177"/>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="178"/>
        <source>Edit selected</source>
        <translation>Éditer la sélection</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="179"/>
        <source>CTRL+SHIFT+E</source>
        <translation>CTRL+MAJ+E</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="181"/>
        <source>&amp;Layout</source>
        <translation>É&amp;tat</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="183"/>
        <source>&amp;Tools</source>
        <translation>Ou&amp;tils</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="184"/>
        <source>Edit selection</source>
        <translation>Éditer la sélection</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="186"/>
        <source>&amp;About</source>
        <translation>À &amp;propos</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="187"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="188"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="253"/>
        <source>Undone: </source>
        <translation>Défaire :</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="258"/>
        <source>Redone: </source>
        <translation>Refaire :</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="302"/>
        <source>Close session</source>
        <translation>Fermer la session</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="303"/>
        <source>The current session is not saved.</source>
        <translation>La session actuelle n&apos;est pas sauvegardée</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.py" line="305"/>
        <source>Discard the changes?</source>
        <translation>Annuler les changements ?</translation>
    </message>
</context>
<context>
    <name>MediaCueMenus</name>
    <message>
        <location filename="../modules/media_cue_menus.py" line="38"/>
        <source>Audio cue (from file)</source>
        <translation>Cue audio (depuis un fichier)</translation>
    </message>
    <message>
        <location filename="../modules/media_cue_menus.py" line="59"/>
        <source>Select media files</source>
        <translation>Sélectionner des fichiers médias</translation>
    </message>
</context>
<context>
    <name>MediaCueSettings</name>
    <message>
        <location filename="../ui/settings/pages/media_cue_settings.py" line="77"/>
        <source>Start time</source>
        <translation>Temps de départ</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/media_cue_settings.py" line="78"/>
        <source>Stop position of the media</source>
        <translation>Position de fin du média</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/media_cue_settings.py" line="80"/>
        <source>Stop time</source>
        <translation>Temps de fin</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/media_cue_settings.py" line="81"/>
        <source>Start position of the media</source>
        <translation>Position de démarrage du média</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/media_cue_settings.py" line="83"/>
        <source>Loop</source>
        <translation>Boucle</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/media_cue_settings.py" line="84"/>
        <source>Repetition after first play (-1 = infinite)</source>
        <translation>Répétition après la première lecture (-1 = infinie)</translation>
    </message>
</context>
<context>
    <name>QColorButton</name>
    <message>
        <location filename="../ui/widgets/qcolorbutton.py" line="40"/>
        <source>Right click to reset</source>
        <translation>Clic-droit pour réinitialiser</translation>
    </message>
</context>
<context>
    <name>SettingsPageName</name>
    <message>
        <location filename="../ui/settings/pages/cue_appearance.py" line="30"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/app_general.py" line="30"/>
        <source>General</source>
        <translation>Générale</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_general.py" line="32"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../ui/settings/pages/cue_app_settings.py" line="29"/>
        <source>Cue Settings</source>
        <translation>Paramètres de cue</translation>
    </message>
</context>
</TS>
